@@ -1,6 +1,6 @@
 from unittest import TestCase
 from uuid import uuid4
-from AsteriskCommand.queue_add import QueueAdd
+from AsteriskCommandApi.queue_add import QueueAdd
 from tests.commands.auxiliar_commands import Auxiliar
 
 
